@@ -78,7 +78,7 @@ class ProgressHandler:
         progress_reporter: Callable[[Dict[Any, Any]], Union[None, Awaitable[None]]],
         error_reporter: Optional[Callable[[str], Union[None, Awaitable[None]]]] = None,
         exception_handler: Optional[
-            Callable[[Exception], Union[None, Awaitable[None]]]
+            Callable[[Dict[str, Any], Exception], Union[None, Awaitable[None]]]
         ] = None,
     ) -> None: # noqa: D107
         self._progress_reporter = progress_reporter
@@ -170,17 +170,21 @@ class ProgressHandler:
                     await self._progress_reporter(**progress)
                 else:
                     self._progress_reporter(**progress)
-            except servo.errors.EventCancelledError:
-                pass  # Event cancellation should not be logged as an error.
             except asyncio.CancelledError:
                 raise
             except Exception as error:  # pylint: disable=broad-except
-                logger.warning(f"encountered exception while processing progress logging: {repr(error)}")
+                logger.warning(f"encountered exception while processing progress logging: {repr(progress)} => {repr(error)}")
                 if self._exception_handler:
-                    if asyncio.iscoroutinefunction(self._exception_handler):
-                        await self._exception_handler(error)
-                    else:
-                        self._exception_handler(error)
+                    try:
+                        if asyncio.iscoroutinefunction(self._exception_handler):
+                            await self._exception_handler(progress, error)
+                        else:
+                            self._exception_handler(progress, error)
+                    except Exception as inner_error:
+                        logger.critical(f"encountered an exception while attempting to handle a progress reporting exception: {repr(progress)} => {repr(inner_error)} from {repr(error)}")
+                        raise inner_error from error
+                else:
+                    logger.warning(f"ignoring exception raised during progress reporting due to lack of handler: {repr(error)}")
             finally:
                 self._queue.task_done()
 
