@@ -1,4 +1,4 @@
-import yaml
+import yaml as _yaml
 
 
 class PreservedScalarString(str):
@@ -12,4 +12,4 @@ def pss_representer(dumper, scalar_string: PreservedScalarString):
     return dumper.represent_scalar(u"tag:yaml.org,2002:str", scalar_string, style="|")
 
 
-yaml.add_representer(PreservedScalarString, pss_representer)
+_yaml.add_representer(PreservedScalarString, pss_representer)
